@@ -12,20 +12,20 @@ class ContactType extends Enum
 {
 
     /**  */
-    const EMAIL = 'email';
+    public const EMAIL = 'email';
 
     /**  */
-    const PHONE = 'phone';
+    public const PHONE = 'phone';
 
     /**  */
-    const PHONE_CLOSE = 'phone_close';
+    public const PHONE_CLOSE = 'phone_close';
 
     /**  */
-    const FAX = 'fax';
+    public const FAX = 'fax';
 
     /**  */
-    const FACEBOOK = 'facebook';
+    public const FACEBOOK = 'facebook';
 
     /**  */
-    const WEBSITE = 'website';
+    public const WEBSITE = 'website';
 }
