@@ -22,4 +22,16 @@ class ConfigLienReservationModel extends AbstractConfigModel
     /** @var  string */
     protected $url;
     //</editor-fold>
+
+    /** @var string */
+    protected $type;
+
+    /** @var string */
+    protected $high_season_price;
+
+    /** @var string */
+    protected $integration_widget;
+
+    /** @var string */
+    protected $price_duration;
 }
